# Bloqade-Shuttle

Bloqade-shuttle is an SDK for simulation and programming neutral atom quantum computers
at the level of atom layout and  shuttling.

The project aims to establish eDSL for programming and optimizing atom layout and
shuttling operations on neutral atom quantum computers. Our goal is to provide a
framework for anyone to use with neutral atom quantum technology.

We welcome industry and academic partners to collaborate to develop Bloqade-shuttle to
further advance neutral atom technology and its applications to quantum computing.

If you are interested in guiding future development of this project, consider becoming a
member of our open source steering committee!  We also welcome contributions via pull
requests, bug reports, or feature requests.

## Installation

```bash
uv add bloqade-shuttle
```
<! TODO: update links to point to documentation website once available. >
See [Installation](install.md) for more details.

Check out new [Blog](blog/index.md) to understand more about tools and shuttle.

## Other useful links

- [Bloqade Geometry](https://queracomputing.github.io/bloqade-geometry/dev/) a related
project that provides components for defining and manipulating geometric objects in
Bloqade Shuttle.

## Stability

Bloqade-Shuttle is currently in active development, while we are gathering feedback from
early users and refining the language design. We can work with our partners to provide
support for transitioning to the new language as well as ongoing maintenance and
updates.
